exceptiontools.NonbinaryTimeSignatureSuppressionError
=====================================================

.. inheritance-diagram:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureSuppressionError.NonbinaryTimeSignatureSuppressionError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
